__version__ = "2.0.2"
from .pururin import get_pur
from .nhentai import get_nh
from .hentaifox import get_hfox
from .hentai2read import get_h2r
from .simplyh import get_sim
from .cli import *
from .utils.misc import choose